@@ -1108,7 +1108,7 @@ def init_globals(gothresh_ini_file="gothresher.ini"):
     config = configparser.ConfigParser()
     config.read(gothresh_ini_file)
     # print("in init_globals")
-    print(config.sections())
+    # print(config.sections())
     global FILE_ALTERNATE_ID_TO_ID_MAPPING 
     global FILE_CAFA_ID_TO_UNIPROT_ID_MAP 
     global FILE_MFO_ONTOLOGY_GRAPH
